@@ -1,11 +1,11 @@
 package SPOPS::Import::Object;
 
-# $Id: Object.pm,v 3.0 2002/08/28 01:16:30 lachoy Exp $
+# $Id: Object.pm,v 3.1 2003/01/02 06:00:23 lachoy Exp $
 
 use strict;
 use base qw( SPOPS::Import );
 
-$SPOPS::Import::Object::VERSION  = sprintf("%d.%02d", q$Revision: 3.0 $ =~ /(\d+)\.(\d+)/);
+$SPOPS::Import::Object::VERSION  = sprintf("%d.%02d", q$Revision: 3.1 $ =~ /(\d+)\.(\d+)/);
 
 my @FIELDS = qw( include_id fields extra_metadata ); # skip_fields 
 SPOPS::Import::Object->mk_accessors( @FIELDS );
@@ -235,6 +235,6 @@ it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
-Chris Winters <chris@cwinters.com>
+Chris Winters E<lt>chris@cwinters.comE<gt>
 
 =cut
