@@ -1,6 +1,6 @@
 package SPOPS::Iterator::LDAP;
 
-# $Id: LDAP.pm,v 3.0 2002/08/28 01:16:30 lachoy Exp $
+# $Id: LDAP.pm,v 3.1 2003/01/02 06:00:22 lachoy Exp $
 
 use strict;
 use base  qw( SPOPS::Iterator );
@@ -9,7 +9,7 @@ use SPOPS           qw( _w DEBUG );
 use SPOPS::Iterator qw( ITER_IS_DONE ITER_FINISHED );
 use SPOPS::Secure   qw( :level );
 
-$SPOPS::Iterator::LDAP::VERSION = sprintf("%d.%02d", q$Revision: 3.0 $ =~ /(\d+)\.(\d+)/);
+$SPOPS::Iterator::LDAP::VERSION = sprintf("%d.%02d", q$Revision: 3.1 $ =~ /(\d+)\.(\d+)/);
 
 # Keys with _LDAP at the beginning are specific to this implementation;
 # keys without _LDAP at the begining are used in all iterators.
@@ -207,6 +207,6 @@ it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
-Chris Winters <chris@cwinters.com>
+Chris Winters E<lt>chris@cwinters.comE<gt>
 
 =cut
