@@ -1,11 +1,11 @@
 package SPOPS::Key::DBI::Pool;
 
-# $Id: Pool.pm,v 3.1 2002/09/03 11:43:21 lachoy Exp $
+# $Id: Pool.pm,v 3.2 2003/01/02 06:00:22 lachoy Exp $
 
 use strict;
 use SPOPS qw( _w DEBUG );
 
-$SPOPS::Key::DBI::Pool::VERSION  = sprintf("%d.%02d", q$Revision: 3.1 $ =~ /(\d+)\.(\d+)/);
+$SPOPS::Key::DBI::Pool::VERSION  = sprintf("%d.%02d", q$Revision: 3.2 $ =~ /(\d+)\.(\d+)/);
 
 
 # Ensure only PRE_fetch_id works.
@@ -117,4 +117,4 @@ it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
-Chris Winters  <chris@cwinters.com>
+Chris Winters  E<lt>chris@cwinters.comE<gt>
