@@ -1,12 +1,12 @@
 package SPOPS::Key::Random;
 
-# $Id: Random.pm,v 3.1 2002/09/03 11:43:22 lachoy Exp $
+# $Id: Random.pm,v 3.2 2003/01/02 06:00:22 lachoy Exp $
 
 use strict;
 use SPOPS  qw( _w DEBUG );
 use SPOPS::Utility;
 
-$SPOPS::Key::Random::VERSION  = sprintf("%d.%02d", q$Revision: 3.1 $ =~ /(\d+)\.(\d+)/);
+$SPOPS::Key::Random::VERSION  = sprintf("%d.%02d", q$Revision: 3.2 $ =~ /(\d+)\.(\d+)/);
 
 use constant DEFAULT_ID_WIDTH => 8;
 
@@ -81,4 +81,4 @@ it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
-Chris Winters  <chris@cwinters.com>
+Chris Winters  E<lt>chris@cwinters.comE<gt>
